@@ -1,6 +1,10 @@
 
 /* Generated data (by glib-mkenums) */
 
+#if !defined (__EPHY_EPIPHANY_H_INSIDE__) && !defined (EPIPHANY_COMPILATION)
+#error Only <epiphany/epiphany.h> can be included directly.
+#endif
+
 #ifndef EPHY_LIB_TYPE_BUILTINS_H
 #define EPHY_LIB_TYPE_BUILTINS_H 1
 
@@ -13,10 +17,6 @@ G_BEGIN_DECLS
 #define EPHY_TYPE_NODE_SIGNAL_TYPE ephy_node_signal_type_get_type()
 GType ephy_node_signal_type_get_type (void);
 
-/* --- ephy-password-dialog.h --- */
-#define EPHY_TYPE_PASSWORD_DIALOG_FLAGS ephy_password_dialog_flags_get_type()
-GType ephy_password_dialog_flags_get_type (void);
-
 /* --- ephy-state.h --- */
 #define EPHY_TYPE_STATE_WINDOW_FLAGS ephy_state_window_flags_get_type()
 GType ephy_state_window_flags_get_type (void);
